@@ -34,5 +34,5 @@ function(flag, sys=0, var1, var2, pCO2a, co3, hco3, S=35, T=20, P=0, Pt=0, Sit=0
 out <- rbind(ci, cf)
 out <- cbind(co, out)
 names(out)[1] <- "comment"
-return(out[,1:15])
+return(out)
 }
